@@ -18,7 +18,11 @@
 #ifndef NMENU_H
 #define NMENU_H
 
-#include <menu.h>
+#if HAVE_LIBNCURSESW == 1 && NCURSESW_HAVE_SUBDIR == 1
+    #include <ncursesw/menu.h>
+#else
+    #include <menu.h>
+#endif
 #include <stdlib.h>
 #include "ngroup.h"
 #include "nscrollbar.h"
