@@ -18,6 +18,8 @@
 #include <string.h>
 #include <algorithm>
 #include <sstream>
+#include <iomanip>
+#include <cmath>
 #include "taskwin.h"
 #include "net.h"
 #include "resultparse.h"
@@ -122,6 +124,18 @@ bool resultCmpLessByEstimate( Item* res1, Item* res2 ) //для сортиров
 }
 
 
+bool resultCmpLessByRcv( Item* res1, Item* res2 ) //для сортировки задач true если res1 < res2
+{
+    Item* received_time1 = res1->findItem("received_time");
+    Item* received_time2 = res2->findItem("received_time");
+    if ( ( received_time1 != NULL) && (received_time2 != NULL) )
+		return (received_time1->getdvalue() > received_time2->getdvalue());
+    if ( ( received_time1 != NULL) && (received_time2 == NULL) )
+		return true;
+    return false;
+}
+
+
 bool resultCmpLessByDL( Item* res1, Item* res2 ) //для сортировки задач true если res1 < res2
 {
     Item* report_deadline1 = res1->findItem("report_deadline");
@@ -136,6 +150,7 @@ bool resultCmpLessByDL( Item* res1, Item* res2 ) //для сортировки 
     return false;
 }
 
+
 /*
 bool resultCmpLessByApp( Item* res1, Item* res2 ) //для сортировки задач true если res1 < res2
 {
@@ -143,6 +158,19 @@ bool resultCmpLessByApp( Item* res1, Item* res2 ) //для сортировки
 }
 */
 
+
+bool resultCmpLessBySwap( Item* res1, Item* res2 ) //для сортировки задач true если res1 < res2
+{
+    Item* swap_size1 = res1->findItem("swap_size");
+    Item* swap_size2 = res2->findItem("swap_size");
+    if ( ( swap_size1 != NULL) && (swap_size2 != NULL) )
+		return (swap_size1->getdvalue() > swap_size2->getdvalue());
+    if ( ( swap_size1 != NULL) && (swap_size2 == NULL) )
+		return true;
+    return false;
+}
+
+
 bool resultCmpLessByTask( Item* res1, Item* res2 ) //для сортировки задач true если res1 < res2
 {
     Item* name1 = res1->findItem("name");
@@ -217,6 +245,23 @@ std::string getresultstatestr(Item* result)
 }
 
 
+std::string gethumanreadablesize(size_t size)
+{
+	std::stringstream s;
+	size_t sizemb=std::round(size/(1024.0*1024.0));
+	if(sizemb==0)
+		s<<"  -  ";
+	else
+	{
+		if(sizemb<9999)
+			s<<sizemb<<"M";
+		else
+			s<<std::round(sizemb/1024.0)<<"G";
+	}
+	return s.str();
+}
+
+
 std::string gethumanreadabletimestr(time_t time) //получить в виде строки прогнозируемое время завершения задачи
 {
     std::stringstream s;
@@ -363,6 +408,7 @@ void TaskWin::updatedata() //обновить данные с сервера
 {
     if (srv == NULL)
 	return;
+	int oldindex=getstartindex();
     clearcontent();
     if (srv->statedom.empty())
 	return;
@@ -389,12 +435,18 @@ void TaskWin::updatedata() //обновить данные с сервера
 		    fcmpless = resultCmpLessByProject; //по project
 		    break;
 		case 4:
-		    fcmpless = resultCmpLessByEstimate; //по estimate
+		    fcmpless = resultCmpLessByRcv; //по rcv
 		    break;
 		case 5:
+		    fcmpless = resultCmpLessByEstimate; //по estimate
+		    break;
+		case 6:
 		    fcmpless = resultCmpLessByDL; //по deadline
 		    break;
-		case 7:
+		case 8:
+		    fcmpless = resultCmpLessBySwap; //по swap
+		    break;
+		case 9:
 		    fcmpless = resultCmpLessByTask; //по task
 		    break;
 	    }//switch
@@ -408,23 +460,23 @@ void TaskWin::updatedata() //обновить данные с сервера
 	    if (name)
 	    {
 		int column = 0;
-		int attr = getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_NORMAL; //ставим цвет по умолчанию
+		int attr = getcolorpair(COLOR_WHITE,getbgcolor()) | A_NORMAL; //ставим цвет по умолчанию
 		NColorString* cs = new NColorString(attr, "");
 		std::string sstate = getresultstatestr(*it); //состояние задачи
 		//цвет и атрибут в зависимости от состояния задачи
 		if ((*it)->findItem("ready_to_report") != NULL)
-		    attr = getcolorpair(COLOR_BLACK,COLOR_BLACK) | A_BOLD;
+		    attr = getcolorpair(getbgcolor(),getbgcolor()) | A_BOLD;
 		if ((*it)->findItem("active_task") != NULL)
-		    attr =  getcolorpair(COLOR_WHITE,COLOR_BLACK) | A_BOLD; //ставим цвет по умолчанию + A_BOLD;
+		    attr =  getcolorpair(COLOR_WHITE,getbgcolor()) | A_BOLD; //ставим цвет по умолчанию + A_BOLD;
 		if ( sstate == "Run")
-		    attr = getcolorpair(COLOR_YELLOW,COLOR_BLACK) | A_BOLD;
+		    attr = getcolorpair(COLOR_YELLOW,getbgcolor()) | A_BOLD;
 		if ( sstate == "Upld")
-		    attr = getcolorpair(COLOR_BLUE,COLOR_BLACK) | A_BOLD;
+		    attr = getcolorpair(COLOR_BLUE,getbgcolor()) | A_BOLD;
 		if ( sstate == "Dwnld")
-		    attr = getcolorpair(COLOR_GREEN,COLOR_BLACK) | A_BOLD;
+		    attr = getcolorpair(COLOR_GREEN,getbgcolor()) | A_BOLD;
 		int stateattr = attr;
 		if (( sstate == "DoneEr" ) || ( sstate == "Abort" ) || ( sstate == "WMem" ))
-		    stateattr = getcolorpair(COLOR_RED,COLOR_BLACK)/* | A_BOLD*/;
+		    stateattr = getcolorpair(COLOR_RED,getbgcolor())/* | A_BOLD*/;
 		//проверяем нужно-ли отображать эту задачу
 		if
 		( !(
@@ -435,7 +487,7 @@ void TaskWin::updatedata() //обновить данные с сервера
 		    continue; //пропускаем задачи не подходящие фильтру tasklistmode
 		//колонка 0 номер задачи
 		if(iscolvisible(column++))
-		    cs->append(attr, " %2d  ", tasknumber++);
+		    cs->append(attr, "%3d  ", tasknumber++);
 		//колонка 1 состояние
 		char sdone[64];
 		if (!fraction_done) //для неактивных секция fraction_done отсутствует
@@ -450,11 +502,11 @@ void TaskWin::updatedata() //обновить данные с сервера
 		if (plan_class != NULL)
 		{
 		    if ((strstr(plan_class->getsvalue(),"ati") != NULL )||(strstr(plan_class->getsvalue(),"opencl") != NULL))
-			attrgpu = getcolorpair(COLOR_MAGENTA,COLOR_BLACK) | A_BOLD;
+			attrgpu = getcolorpair(COLOR_MAGENTA,getbgcolor()) | A_BOLD;
 		    if (strstr(plan_class->getsvalue(),"cuda") != NULL )
-			attrgpu = getcolorpair(COLOR_GREEN,COLOR_BLACK) | A_BOLD;
+			attrgpu = getcolorpair(COLOR_GREEN,getbgcolor()) | A_BOLD;
 		    if (strstr(plan_class->getsvalue(),"intel") != NULL ) //NEED CHECK !!!
-			attrgpu = getcolorpair(COLOR_BLUE,COLOR_BLACK) | A_BOLD;
+			attrgpu = getcolorpair(COLOR_BLUE,getbgcolor()) | A_BOLD;
 		}
 		if (( sstate != "Run" )||( sstate != "Done"))
 		//    attrgpu = attrgpu & (~A_BOLD); //выключаем болд для незапущенных
@@ -475,7 +527,7 @@ void TaskWin::updatedata() //обновить данные с сервера
 		    {
 			double dtime = estimated_cpu_time_remaining->getdvalue();
 			if ( ( sstate == "Run" )&&( dtime < 600)&&( dtime >= 0 ) ) //осталось [0-600[ сек
-			    attr2 = getcolorpair(COLOR_RED,COLOR_BLACK) | A_BOLD;
+			    attr2 = getcolorpair(COLOR_RED,getbgcolor()) | A_BOLD;
 			if ( dtime >= 0)
 			    cs->append(attr2," %4s", gethumanreadabletimestr(dtime).c_str()); //естимейт
 			else
@@ -484,7 +536,21 @@ void TaskWin::updatedata() //обновить данные с сервера
 		    else
 			cs->append(attr2," %4s", "?");
 		}
-		//колонка 5 время дедлайн
+		//колонка 5 received time column
+		if(iscolvisible(column++))
+		{
+		    Item* received_time = (*it)->findItem("received_time");
+		    int attr2 = attr;
+		    if (received_time != NULL)
+		    {
+				double dtime = received_time->getdvalue();
+				double beforedl = time(NULL) - dtime; //число секунд c момента получениия задачи
+				cs->append(attr2," %4s", gethumanreadabletimestr(beforedl).c_str());
+		    }
+		    else
+				cs->append(attr," %4s", "?");
+		}
+		//колонка 6 время дедлайн
 		if(iscolvisible(column++))
 		{
 		    Item* report_deadline = (*it)->findItem("report_deadline");
@@ -494,13 +560,13 @@ void TaskWin::updatedata() //обновить данные с сервера
 			double dtime = report_deadline->getdvalue();
 			double beforedl = dtime - time(NULL); //число секунд до дедлайна
 			if ( ( sstate != "Done")&&( beforedl < 3600 * 24 * 2) ) //осталось меньше 2-х дней
-			    attr2 = getcolorpair(COLOR_BLUE,COLOR_BLACK) | A_BOLD;
+			    attr2 = getcolorpair(COLOR_BLUE,getbgcolor()) | A_BOLD;
 			cs->append(attr2," %4s", (beforedl>0) ? gethumanreadabletimestr(beforedl).c_str() : "dead");
 		    }
 		    else
 			cs->append(attr2," %4s", "?");
 		}
-		//колонка 6 имя приложения
+		//колонка 7 имя приложения
 		if(iscolvisible(column++))
 		{
 		    char buf[256];
@@ -520,7 +586,18 @@ void TaskWin::updatedata() //обновить данные с сервера
 			mbstrtrunc(buf,30);
 		    cs->append(attr,"  %-30s", buf);
 		}
-		//колонка 7 имя задачи
+		//колонка 8 swap size
+		if(iscolvisible(column++))
+		{
+		    Item* swap_size = (*it)->findItem("swap_size");
+		    if (swap_size != NULL)
+		    {
+				cs->append(attr," %5s ", gethumanreadablesize(swap_size->getdvalue()).c_str());
+			}
+		    else
+				cs->append(attr," %5s ", " - ");
+		}
+		//колонка 9 имя задачи
 		if(iscolvisible(column++))
 		    cs->append(attr,"  %s", name->getsvalue()); 
 		//добавляем сформированную строку и поле данных с именем задачи (для селектора)
@@ -531,6 +608,7 @@ void TaskWin::updatedata() //обновить данные с сервера
 	} //цикл списка задач
     }
     srv->statedom.releaseptr(tmpstatedom);
+	setstartindex(oldindex);
 }
 
 
